<?php

namespace Spec\Infomaker\Everyware\Support;

use Infomaker\Everyware\Support\Environment;
use PhpSpec\ObjectBehavior;
use Prophecy\Argument;

class EnvironmentSpec extends ObjectBehavior
{
    public function it_is_initializable()
    {
        $this->shouldHaveType(Environment::class);
    }

    public function it_should_default_to_development_environment()
    {
        $this->current()->shouldReturn(Environment::DEVELOPMENT);
    }

    public function it_should_provide_setter_and_getter_for_current_environment()
    {
        $this->setCurrent(Environment::DEVELOPMENT);
        $this->current()->shouldReturn(Environment::DEVELOPMENT);

        $this->setCurrent(Environment::PRODUCTION);
        $this->current()->shouldReturn(Environment::PRODUCTION);

        $this->setCurrent(Environment::STAGED);
        $this->current()->shouldReturn(Environment::STAGED);
    }

    public function it_should_provide_helper_function_for_determening_environment()
    {
        $this->setCurrent(Environment::DEVELOPMENT);
        $this->isDev()->shouldReturn(true);
        $this->isProd()->shouldReturn(false);
        $this->isStage()->shouldReturn(false);

        $this->setCurrent(Environment::PRODUCTION);
        $this->isDev()->shouldReturn(false);
        $this->isProd()->shouldReturn(true);
        $this->isStage()->shouldReturn(false);

        $this->setCurrent(Environment::STAGED);
        $this->isDev()->shouldReturn(false);
        $this->isProd()->shouldReturn(false);
        $this->isStage()->shouldReturn(true);
    }

    public function it_shouldnt_allow_wrong_device_to_be_set()
    {
        $this->shouldThrow(\InvalidArgumentException::class)->during('setCurrent', ['invalid']);
    }

}
